@@ -5,9 +5,6 @@ import logging
 logger = logging.getLogger("x-pages")
 
 def page(request, route=None):
-    logger.debug(route.content)
     ctx = route.get_context(request)
-    logger.debug(route.content)
-    route.increment_view_count()
-    logger.debug(route.content)
+    route.increment_view_count(request)
     return render_to_response(request.theme.template().page, ctx, RequestContext(request))
